@@ -13,7 +13,7 @@ from . import indexer
 from . import equilibrium as eq
 from . import functional as fn
 from . import units_of_measure as thermo_units
-from .exceptions import DimensionError, DomainError, InfeasibleRegion
+from .exceptions import DimensionError
 from . import utils
 
 __all__ = ('Stream', )
@@ -756,29 +756,17 @@ class Stream:
             self._imol.mix_from([i._imol for i in others])
             H = sum([i.H for i in others])
             try: self.H = H
-            except DomainError as error: 
-                if hasattr(error, 'T'):
-                    # Temperature outside domain of heat capacity model
-                    if error.T <= error.Tmin:
-                        # Too little heat, liquid must be present
-                        self.phase = 'l'
-                    elif error.T >= error.Tmax:
-                        # Too much heat, gas must be present
-                        self.phase = 'g'
-                    else:
-                        raise error # Problem with domain
-                    self.H = H
-            except InfeasibleRegion as error: 
-                if error.region == 'negative temperature': 
+            except Exception as error:
+                if self.phase == 'g':
+                     # Maybe much heat, gas must be present
+                    self.phase = 'l'
+                elif self.phase.lower() == 'l':
+                    # Maybe too little heat, liquid must be present
                     self.phase = 'g'
-                    self.H = H
                 else:
                     raise error
-            else: pass
+                self.H = H
             
-                        
-                    
-    
     def split_to(self, s1, s2, split):
         """
         Split molar flow rate from this stream to two others given
