@@ -57,9 +57,15 @@ References
 """
 from math import log, exp
 from ..base import functor, TDependentHandleBuilder, InterpolatedTDependentModel
-from .utils import CASDataReader
 from .._constants import N_A, k
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
+from .data import (VDI_saturation_dict,
+                   VDI_tabular_data,
+                   sigma_data_Mulero_Cachadina,
+                   sigma_data_Jasper_Lange,
+                   sigma_data_Somayajulu,
+                   sigma_data_Somayajulu_2,
+                   sigma_data_VDI_PPDS_11,
+)
 from .dippr import DIPPR_EQ106
 
 __all__ = ('REFPROP', 
@@ -74,13 +80,6 @@ __all__ = ('REFPROP',
            'Mersmann_Kind'
 )
 
-read = CASDataReader(__file__, 'Interface')
-_Mulero_Cachadina = read('MuleroCachadinaParameters.tsv')
-_Jasper_Lange = read('Jasper-Lange.tsv')
-_Somayajulu = read('Somayajulu.tsv')
-_Somayajulu_2 = read('SomayajuluRevised.tsv')
-_VDI_PPDS_11 = read('VDI PPDS surface tensions.tsv')
-
 
 ### Regressed coefficient-based functions
 
@@ -555,17 +554,17 @@ def Mersmann_Kind(T, Tm, Tb, Tc, Pc, n_associated=1):
 @TDependentHandleBuilder('sigma')
 def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar):
     add_model = handle.add_model
-    if CAS in _Mulero_Cachadina:
-        _, sigma0, n0, sigma1, n1, sigma2, n2, Tc, Tmin, Tmax = _Mulero_Cachadina[CAS]
+    if CAS in sigma_data_Mulero_Cachadina:
+        _, sigma0, n0, sigma1, n1, sigma2, n2, Tc, Tmin, Tmax = sigma_data_Mulero_Cachadina[CAS]
         STREFPROP_coeffs = (Tc, sigma0, n0, sigma1, n1, sigma2, n2)
         add_model(REFPROP.from_args(STREFPROP_coeffs), Tmin, Tmax)
-    if CAS in _Somayajulu_2:
-        _, Tt, Tc, a, b, c = _Somayajulu_2[CAS]
+    if CAS in sigma_data_Somayajulu_2:
+        _, Tt, Tc, a, b, c = sigma_data_Somayajulu_2[CAS]
         SOMAYAJULU2_coeffs = (Tc, a, b, c)
         Tmin = Tt; Tmax = Tc
         add_model(Somayajulu.from_args(SOMAYAJULU2_coeffs), Tmin, Tmax)
-    elif CAS in _Somayajulu:
-        _, Tt, Tc, a, b, c = _Somayajulu[CAS]
+    elif CAS in sigma_data_Somayajulu:
+        _, Tt, Tc, a, b, c = sigma_data_Somayajulu[CAS]
         SOMAYAJULU_coeffs = (Tc, a, b, c)
         Tmin = Tt; Tmax = Tc
         add_model(Somayajulu.from_args(SOMAYAJULU_coeffs), Tmin, Tmax)
@@ -575,8 +574,8 @@ def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPola
         *Ts, Tmax = Ts
         Ys = Ys[:-1]
         add_model(InterpolatedTDependentModel(Ts, Ys), Tmin, Tmax)
-    if CAS in _Jasper_Lange:
-        _, a, b, Tmin, Tmax= _Jasper_Lange[CAS]
+    if CAS in sigma_data_Jasper_Lange:
+        _, a, b, Tmin, Tmax= sigma_data_Jasper_Lange[CAS]
         JASPER_coeffs = (a, b)
         add_model(Jasper.from_args(JASPER_coeffs))
     data = (Tc, Vc, omega)
@@ -590,7 +589,7 @@ def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPola
     if all(data):
         add_model(Pitzer.from_args(data), 0.0, Tc)
         add_model(Zuo_Stenby.from_args(data), 0.0, Tc)
-    if CAS in _VDI_PPDS_11:
-        _, Tm, Tc, a, b, c, d, e = _VDI_PPDS_11[CAS]
+    if CAS in sigma_data_VDI_PPDS_11:
+        _, Tm, Tc, a, b, c, d, e = sigma_data_VDI_PPDS_11[CAS]
         VDI_PPDS_coeffs = (Tc, a, b, c, d, e)
         add_model(DIPPR_EQ106.from_args(VDI_PPDS_coeffs))
