@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# This module is under the UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
 """
-Created on Thu Nov 28 22:59:17 2019
-
-@author: yoelr
 """
 __all__ = ('repr_IDs_data', 'repr_kwargs', 'repr_kwarg', 'repr_couples',
            'repr_listed_values')
